@@ -30,9 +30,9 @@
 //
 
 #define APP_NAME_ "CheeseTracker "
-#define APP_VERSION_ "0.9.15.2"
+#define APP_VERSION_ "0.9.15.3"
 #define APP_AUTHOR_ "(c) 1999,2004 Juan Linietsky"
-#define APP_RELEASE_DATE_ "Sun Aug 26 15:12:13 EDT 2007"
+#define APP_RELEASE_DATE_ "Mon Dec 31 06:19:03 EST 2007"
 #define APP_MAINTAINER_ "J Phelps <godless@users.sf.net>"
 #define APP_WEBSITE_ "http://cheesetracker.sf.net/"
 
@@ -694,8 +694,8 @@ MDI_Main_Window::MDI_Main_Window() : QMainWindow( 0, "Main Window"/*, WDestructi
 	pattern_edit_menu->setAccel(Qt::ALT+Qt::Key_B ,Editor::Pattern_MARK_BLOCK_BEGIN);
 	pattern_edit_menu->insertItem("Mark- Block End",Editor::Pattern_MARK_BLOCK_END);
 	pattern_edit_menu->setAccel(Qt::ALT+Qt::Key_E ,Editor::Pattern_MARK_BLOCK_END);
-	pattern_edit_menu->insertItem("Mark- Sixteen notes", Editor::Pattern_MARK_COLUMN_SIXTEEN);
-	pattern_edit_menu->setAccel(Qt::ALT+Qt::Key_D, Editor::Pattern_MARK_COLUMN_SIXTEEN);
+	pattern_edit_menu->insertItem("Mark- quarter/half pattern length notes", Editor::Pattern_MARK_COLUMN_QUARTER_HALF);
+	pattern_edit_menu->setAccel(Qt::ALT+Qt::Key_D, Editor::Pattern_MARK_COLUMN_QUARTER_HALF);
 	pattern_edit_menu->insertItem("Mark- Toggle Column/All",Editor::Pattern_MARK_COLUMN_ALL);
 	pattern_edit_menu->setAccel(Qt::ALT+Qt::Key_L ,Editor::Pattern_MARK_COLUMN_ALL);
 	pattern_edit_menu->insertSeparator();
