@@ -40,7 +40,7 @@ void Sample_Edit::destructive_operation_begin_cbk() {
 
 	rt_keyboard->sample_stop_all(NO_MUTEX);
         player->lock_player_variables(__FILE__, __LINE__);
-	player->erase_voices_using_sample(dst_sample);
+	player->erase_voices_using_sample(dst_sample, false);
 
 }
 
@@ -440,6 +440,7 @@ Sample_Edit::Sample_Edit(QWidget *p_parent) : QHBox(p_parent)  {
 	sample_editor->add_edit_effect(&edit_effects.reverse);
 	sample_editor->add_edit_effect(&edit_effects.center);
 	sample_editor->add_edit_effect(&edit_effects.normalize);
+	sample_editor->add_edit_effect(&edit_effects.trim);
 	sample_editor->add_edit_effect(&edit_effects.pre_cut);
 	sample_editor->add_edit_effect(&edit_effects.post_cut);
 	sample_editor->add_edit_effect(&edit_effects.tunner);
