@@ -19,6 +19,8 @@
 #include "interface_binds/editor.h"
 
 #include <qfiledialog.h>
+#include <qcheckbox.h>
+#include <qvbox.h>
 /**
 @author Juan Linietsky
 */
@@ -26,6 +28,9 @@ class Sample_Player_FDialog : public QFileDialog {
 
 	Q_OBJECT
 
+	QCheckBox *audition;
+	bool audition_mode;
+
 	struct Vars {
 		File_Format_Manager *file_manager;
 		Player_Realtime_Keyboard *rt_keyboard;
@@ -39,9 +44,11 @@ class Sample_Player_FDialog : public QFileDialog {
 	} preview;
 
 	bool eventFilter(QObject *p_obj,QEvent *p_event);
+	void position_audition_checkbox();
 
 protected slots:
 	void filename_hilite_slot(const QString& p_file);
+	void audition_slot(bool p_on);
 public:
 
 	void set_binds(File_Format_Manager *p_file_manager,Player_Realtime_Keyboard *p_rt_keyboard);
