@@ -14,13 +14,13 @@
 #include "components/data/dds_packer.h"
 
 #define FILE_FORMAT_MAJOR 1
-#define FILE_FORMAT_MINOR 1
+#define FILE_FORMAT_MINOR 2
 
 
 
 void Loader_CT::set_dds_to_sample(DDS *p_dds,Sample *p_sample) {
 
-	p_sample->prop_name.set( p_dds->get_str_var("name") );
+	p_sample->prop_name.set( basename(p_dds->get_str_var("name").c_str()) );
 	p_sample->prop_def_volume.set( p_dds->get_int_var("def_volume") );
 	p_sample->prop_glb_volume.set( p_dds->get_int_var("glb_volume") );
 	p_sample->prop_def_panning_on .set( p_dds->get_int_var("def_panning_active") );
@@ -280,11 +280,6 @@ Loader::Error Loader_CT::load(const char *p_filename,bool p_load_patterns) {
 
 	Uint32 length=file_read.get_dword();
 	Uint32 compressed_length=file_read.get_dword();
-	if (length>(50*1024*1024)) {
-		file_read.close();
-                ERROR("uncompressed file is just too big, this cant be true");
-		return FILE_FORMAT_NOT_RECOGNIZED;
-	}
 	if (compressed_length>length) {
 		file_read.close();
                 ERROR("File compressed cant be greater than uncompressed");
@@ -404,11 +399,6 @@ Loader::Error Loader_CT::load_sample(const char *p_filename,int p_dest_index) {
 
 	Uint32 length=file_read.get_dword();
 	Uint32 compressed_length=file_read.get_dword();
-	if (length>(50*1024*1024)) {
-		file_read.close();
-                ERROR("uncompressed file is just too big, this cant be true");
-		return FILE_FORMAT_NOT_RECOGNIZED;
-	}
 	if (compressed_length>length) {
 		file_read.close();
                 ERROR("File compressed cant be greater than uncompressed");
@@ -442,7 +432,7 @@ Loader::Error Loader_CT::load_sample(const char *p_filename,int p_dest_index) {
 	set_dds_to_sample(&base,song->get_sample(p_dest_index));
 	
         
-	return FILE_ERROR;
+	return SUCCESS;
 }
 
 Sample_Data *Loader_CT::load_sample(const char *p_filename) {
@@ -476,11 +466,6 @@ Sample_Data *Loader_CT::load_sample(const char *p_filename) {
 
 	Uint32 length=file_read.get_dword();
 	Uint32 compressed_length=file_read.get_dword();
-	if (length>(50*1024*1024)) {
-		file_read.close();
-                ERROR("uncompressed file is just too big, this cant be true");
-		return NULL;
-	}
 	if (compressed_length>length) {
 		file_read.close();
                 ERROR("File compressed cant be greater than uncompressed");
@@ -555,11 +540,6 @@ Loader::Error Loader_CT::load_instrument(const char *p_filename,int p_dest_index
 
 	Uint32 length=file_read.get_dword();
 	Uint32 compressed_length=file_read.get_dword();
-	if (length>(50*1024*1024)) {
-		file_read.close();
-                ERROR("uncompressed file is just too big, this cant be true");
-		return FILE_FORMAT_NOT_RECOGNIZED;
-	}
 	if (compressed_length>length) {
 		file_read.close();
                 ERROR("File compressed cant be greater than uncompressed");
