@@ -34,7 +34,7 @@
  ***************************************************************************/
 #include "loader_it.h"
 #include "player_data.h"
-
+#include "ns_autoptr.h"
 
 
 
@@ -56,7 +56,7 @@ Loader::Error Loader_IT::load_sample_info(IT_Sample *p_sample) {
        	file_read.get_byte_array((Uint8*)p_sample->sampname,26);
        	p_sample->convert=file_read.get_byte();	/* sample conversion flag */
        	p_sample->panning=file_read.get_byte();
-	int sample_size=file_read.get_dword();
+	size_t sample_size=file_read.get_dword();
        	p_sample->data.set_loop_begin( file_read.get_dword() );
 	p_sample->data.set_loop_end( file_read.get_dword() );
 	p_sample->c5spd=file_read.get_dword();
@@ -70,15 +70,11 @@ Loader::Error Loader_IT::load_sample_info(IT_Sample *p_sample) {
 
 	p_sample->data.set_loop_enabled( (p_sample->flag >> 4) & 1);
 	p_sample->data.set_loop_ping_pong((p_sample->flag >> 6) & 1);
-//	p_sample->data.sustain_loop_on=(p_sample->flag >> 5) & 1;
-//	p_sample->data.sustain_pingpong_loop=(p_sample->flag >> 7) & 1;
 
-	p_sample->data.set_data_ptr(NULL,sample_size,(p_sample->flag >> 1) & 1);
+	p_sample->data.set_size(sample_size);
 
 	p_sample->data.set_c5_freq(p_sample->c5spd);
-	//p_sample->data.import_frequency(p_sample->c5spd);
 
-	//p_sample->data.data_ptr=NULL;
 	p_sample->header[4]=0;
 	p_sample->filename[13]=0;
 	p_sample->sampname[29]=0;
@@ -89,68 +85,140 @@ Loader::Error Loader_IT::load_sample_info(IT_Sample *p_sample) {
 
 Loader::Error Loader_IT::load_sample_data(IT_Sample *p_sample) {
 
-	if ((p_sample->flag & IT_SAMPLE_EXISTS) && ((p_sample->flag & IT_SAMPLE_STEREO)==0) ) { // stereo not supported
 
-		int aux_sample_properties = p_sample->flag & 10; // 2nd and 4th bytes only
+	if ((p_sample->flag & IT_SAMPLE_EXISTS)) { 
+		int aux_sample_properties = p_sample->flag & 10; // 2nd and 4th bits only
 
-			file_read.seek(p_sample->sampoffset);
+		file_read.seek(p_sample->sampoffset);
+		Mutex_Lock_Container *lock = p_sample->data.lock(__FILE__, __LINE__);
+		ns_autoptr<Mutex_Lock_Container> ns_lock;
+		ns_lock.ptr_new(lock);
+		p_sample->data.seek(0);
 
-			switch (aux_sample_properties) {
+		if(aux_sample_properties & IT_SAMPLE_COMPRESSED) {
+				size_t size = p_sample->data.get_size();
+				int multiplier=1;
+				if(aux_sample_properties & IT_SAMPLE_16BITS)
+					size *= 2;
+				if(aux_sample_properties & IT_SAMPLE_STEREO) {
+					size *= 2;
+					multiplier=2;
+					p_sample->data.set_num_channels(2);
+				} else {
+					p_sample->data.set_num_channels(1);
+				}
 
-				case (0): { // 8 bits
+				char *auxdest=new char[size];
+				ns_autoptr<char> ns_auxdest;
+				ns_auxdest.arr_new(auxdest);
+				int status=0;
+
+				// FIXME: Are these decompressors nearly identical?
+				// The decompressors are assumed to handle only mono
+				// samples (since the original author programmed this
+				// function to give up if stereo was encountered).
+				//
+				// Therefore, twice as many samples will be decompressed
+				// if the sample is stereo, resulting in the need for
+				// the multiplier.
+
+				if(aux_sample_properties & IT_SAMPLE_16BITS) 
+					status = load_sample_16bits_IT_compressed((void*)auxdest, p_sample->data.get_size()*multiplier);
+				else
+					status = load_sample_8bits_IT_compressed((void*)auxdest, p_sample->data.get_size()*multiplier);
+
+				if ( status ) {
+
+					return FILE_ERROR;
+				}
 
 
+				if(aux_sample_properties & IT_SAMPLE_STEREO) {
+					size_t jx;
 
-					void *auxdest=malloc(p_sample->data.get_size());
-					file_read.get_byte_array((Uint8*)auxdest,p_sample->data.get_size());
-					p_sample->data.set_data_ptr(auxdest);
+					// What's this? It's called, "Proper handling of stereo."
+					// Added Sun Apr 8 02:53:35 EDT 2007 by <godless@users.sf.net>
 
-				} break;
-				case (IT_SAMPLE_16BITS): { // 16 bits
+					// jx increments by two samples (either 8 or 16 bit) and will not exceed
+					// the size of the auxdest buffer because auxdest is twice as big, being
+					// composed of pairs of samples instead of just individuals.
+					//
 
-					//p_sample->data.data_ptr=(Sint16 *)malloc(p_sample->data.size*2);
-					//file_read.get_byte_array((Uint8*)p_sample->data.data_ptr,p_sample->data.size*2);
+					sample_int_t buffer[2];
 
-					void *auxdest=malloc(p_sample->data.get_size()*2);
-					file_read.get_word_array((Uint16*)auxdest,p_sample->data.get_size());
-					p_sample->data.set_data_ptr(auxdest);
-
-				} break;
-				case (IT_SAMPLE_COMPRESSED): { // 8 bits compressed
-
-
-					void *auxdest=malloc(p_sample->data.get_size());
-
-					if ( load_sample_8bits_IT_compressed((void*)auxdest,p_sample->data.get_size()) ) {
-
-						free(auxdest);
-						return FILE_ERROR;
+					for(jx=0; !p_sample->data.eof_reached(); jx+=2) {
+						for(size_t chan=0; chan < p_sample->data.num_channels(); chan++) {
+							if(aux_sample_properties & IT_SAMPLE_16BITS) {
+								buffer[chan] = CONVERT_FROM_TYPE(Sint16, ((Sint16*)auxdest)[jx+chan]);
+							} 
+							else {
+								buffer[chan] = CONVERT_FROM_TYPE(Sint8, ((Sint8*)auxdest)[jx+chan]);
+							}
+						}
+						p_sample->data.put_sample(buffer);
 					}
+					// The convert flag simply specifies if the sample is signed.
+					// Other bits were proposed, but never implemented in Impulse
+					// Tracker.
 
-					p_sample->data.set_data_ptr(auxdest);
+					if(!p_sample->convert)
+						p_sample->data.change_sign();
+				}
+				else { // COMPRESSED MONO
 
+					sample_int_t buffer;
 
-				} break;
-				case (IT_SAMPLE_16BITS|IT_SAMPLE_COMPRESSED): { // 16 bits compressed
-
-
-					void *auxdest=malloc(p_sample->data.get_size()*2);
-
-					if ( load_sample_16bits_IT_compressed(auxdest,p_sample->data.get_size()) ) {
-
-						free(auxdest);
-						return FILE_ERROR;
+					for(size_t ix=0; !p_sample->data.eof_reached(); ix++) {
+						if(p_sample->flag & IT_SAMPLE_16BITS) 
+							buffer=CONVERT_FROM_TYPE(Uint16, ((Uint16*)auxdest)[ix]);
+						else
+							buffer=CONVERT_FROM_TYPE(Uint8, ((Uint8*)auxdest)[ix]);
+						p_sample->data.put_sample(&buffer);
 					}
-					p_sample->data.set_data_ptr(auxdest);
+				}
+			} else { // NOT COMPRESSED
+				// IT is a dead format: It will never change to the point where more than
+				// two channels will need to be supported. Compare this with the WAV
+				// loader, where a proper channel loop is used because WAV format can
+				// specify more than two channels.
 
-				} break;
+				size_t size = p_sample->data.get_size();
+
+				if(p_sample->flag & IT_SAMPLE_STEREO) {
+					p_sample->data.set_num_channels(2);
+					p_sample->data.set_size(size/2);
+
+					while(!p_sample->data.eof_reached()) {
+						sample_int_t buffer[2];
+						for(size_t chan=0; chan<2; chan++) {
+							if(p_sample->flag & IT_SAMPLE_16BITS) {
+								buffer[chan] = CONVERT_FROM_TYPE(Sint16, file_read.get_word());
+							}
+							else {
+								buffer[chan] = CONVERT_FROM_TYPE(Sint8, file_read.get_byte());
+							}
+						}
+						p_sample->data.put_sample(buffer);
+
+					}
+				} else { // MONO
+					sample_int_t buffer;
+					p_sample->data.set_num_channels(1);
+					p_sample->data.set_size(size);
+
+					while(!p_sample->data.eof_reached()) {
+						if(p_sample->flag & IT_SAMPLE_16BITS) 
+							buffer=CONVERT_FROM_TYPE(Sint16, file_read.get_word());
+						else
+							buffer=CONVERT_FROM_TYPE(Sint8, file_read.get_byte());
+						p_sample->data.put_sample(&buffer);
+					}
+				}
 
 			}
 
-	} else {
 
-			p_sample->data.release_data_ptr();
-	}
+	} 
 
 	return SUCCESS;
 }
@@ -545,6 +613,7 @@ void Loader_IT::transfer_sample_to_song(IT_Sample *p_src_sample,int p_dst_index)
 
 	song->get_sample(p_dst_index)->reset(); // <- just to make sure that nothing bad might happen!
 
+	song->get_sample(p_dst_index)->data=p_src_sample->data;
 	song->get_sample(p_dst_index)->name=p_src_sample->sampname;
 	song->get_sample(p_dst_index)->def_volume=p_src_sample->volume;
 	song->get_sample(p_dst_index)->glb_volume=p_src_sample->globvol;
@@ -554,8 +623,6 @@ void Loader_IT::transfer_sample_to_song(IT_Sample *p_src_sample,int p_dst_index)
 	song->get_sample(p_dst_index)->vibrato_speed=p_src_sample->vibspeed;
 	song->get_sample(p_dst_index)->vibrato_depth=p_src_sample->vibdepth;
 	song->get_sample(p_dst_index)->vibrato_rate=p_src_sample->vibrate;
-//		song->get_sample(p_dst_index)->data.base_speed=p_src_sample->c5spd;
-	song->get_sample(p_dst_index)->data=p_src_sample->data;
 
 	song->get_sample(p_dst_index)->in_use=p_src_sample->flag & IT_SAMPLE_EXISTS;
 
@@ -568,7 +635,8 @@ int Loader_IT::get_amount_of_samples() {
 
 	for (i=0;i<sample_count;i++) {
 
-		if ((sample[i]->data.get_data_16()!=NULL) || (sample[i]->data.get_size()!=0)) count++;
+		if (!sample[i]->data.is_empty())
+			count++;
 	}
 
 	return count;
@@ -582,7 +650,7 @@ Sample_Data *Loader_IT::get_sample_data(int p_sample_index) {
 
 	for (i=0;i<sample_count;i++) {
 
-		if ((sample[i]->data.get_data_16()!=NULL) || (sample[i]->data.get_size()!=0)) {
+		if (!sample[i]->data.is_empty()) {
 
 			if (count==p_sample_index) break;
 			count++;
@@ -600,7 +668,7 @@ string Loader_IT::get_sample_name(int p_sample_index) {
 
 	for (i=0;i<sample_count;i++) {
 
-		if ((sample[i]->data.get_data_16()!=NULL) || (sample[i]->data.get_size()!=0)) {
+		if (!sample[i]->data.is_empty()) {
 
 			if (count==p_sample_index) break;
 			count++;
@@ -620,7 +688,7 @@ void Loader_IT::add_sample_to_song(int p_sample_index,int p_dest_index,bool crea
 
 	for (i=0;i<sample_count;i++) {
 
-		if ((sample[i]->data.get_data_16()!=NULL) || (sample[i]->data.get_size()!=0)) {
+		if (!sample[i]->data.is_empty()) {
 
 			if (count==p_sample_index) break;
 			count++;
@@ -629,7 +697,6 @@ void Loader_IT::add_sample_to_song(int p_sample_index,int p_dest_index,bool crea
 
 	song->get_sample(p_dest_index)->reset();
 	transfer_sample_to_song(sample[i],p_dest_index);
-	sample[i]->data.release_data_ptr();
 
 	if (create_instrument) {
 
@@ -698,7 +765,6 @@ Sample_Data *Loader_IT::load_sample(const char *p_filename) {
 
 	Sample_Data *new_sample = new Sample_Data;
 	*new_sample=p_sample.data;
-	p_sample.data.release_data_ptr();
 
 	return new_sample;
 }
