@@ -36,7 +36,9 @@
 #include "loader_xm.h"
 
 #define ABORT_LOAD  { reader.close(); \
-	for (int x=0;x<(int)samples.size();x++) samples[x].data.set_data_ptr(NULL); \
+	for (size_t x=0;x<samples.size();x++) {\
+		samples[x].data.set_size(0);				\
+	}								\
  	samples.clear(); \
   	instruments.clear(); \
     	return FILE_FORMAT_NOT_RECOGNIZED; }
@@ -113,7 +115,7 @@ Loader::Error Loader_XM::load(const char *p_filename,bool p_load_patterns) {
 
           	Uint32 aux,rows;
 
-           	aux=reader.get_dword(); //length
+		aux=reader.get_dword(); //length
            	aux=reader.get_byte(); //packing type
            	rows=aux=reader.get_word(); //rows!
 
@@ -122,12 +124,11 @@ Loader::Error Loader_XM::load(const char *p_filename,bool p_load_patterns) {
             	if (aux==0)
              		continue;
                 //unpaaack!
-		for(int j=0;j<rows;j++)
+		for(Uint32 j=0;j<rows;j++)
 			for(int k=0;k<header.channels_used;k++) {
 
      				Note aux_note;
          			Uint8 aux_byte;
-         			Uint8 field;
 	                    	aux_byte=reader.get_byte(); //packing type
                       		if (!(aux_byte&0x80)) {
 
@@ -494,11 +495,23 @@ Loader::Error Loader_XM::load_instrument_internal(Instrument *p_instr,bool p_xi,
 
 			if ((reader.get_file_pos()-p_cpos)<p_hsize) {
 
-				Uint8 junkbuster[500];
+				// Allocate a buffer big enough for the
+				// data being read
+
+				Uint8 *junkbuster = new Uint8 [p_hsize-(reader.get_file_pos()-p_cpos)];
+
+				// return in error if it can't be
+				// allocated
+				if(!junkbuster)
+					return FILE_ERROR;
 
 				//printf("extra junk XM instrument in header! hsize is %i, extra junk: %i\n",p_hsize,(reader.get_file_pos()-p_cpos));
 
 				reader.get_byte_array((Uint8*)junkbuster,p_hsize-(reader.get_file_pos()-p_cpos));
+
+				// Fix Debian memory leak.
+
+				delete[] junkbuster;
 			}
 			sampnum=p_sampnum;
 
@@ -519,14 +532,17 @@ Loader::Error Loader_XM::load_instrument_internal(Instrument *p_instr,bool p_xi,
 
 
 		/*SAMPLE!!*/
+		size_t sample_size;
+		bool sample_is_16bits;
+		Sample sample;
 
 		for (int j=0;j<sampnum;j++) {
 
 			if (j>16) ABORT_LOAD;
 
 			char auxb;
-			Sample sample;
-			int sample_size=reader.get_dword();
+			sample.data.set_num_channels(1);
+			sample_size=reader.get_dword();
 			sample.data.set_loop_begin( reader.get_dword() );
 
 			sample.data.set_loop_end( reader.get_dword() );
@@ -536,7 +552,7 @@ Loader::Error Loader_XM::load_instrument_internal(Instrument *p_instr,bool p_xi,
 			aux=reader.get_byte();
 			sample.data.set_loop_enabled( aux&3 );
 			sample.data.set_loop_ping_pong( aux&2 );
-			bool sample_is_16bits=aux&16;
+			sample_is_16bits=aux&16;
 
 
 			if (sample_is_16bits){
@@ -545,9 +561,9 @@ Loader::Error Loader_XM::load_instrument_internal(Instrument *p_instr,bool p_xi,
 				sample.data.set_loop_begin( sample.data.get_loop_begin()/2 );
 				sample.data.set_loop_end( sample.data.get_loop_end()/2 );
 			}
-
-			sample.data.set_data_ptr(NULL,sample_size,sample_is_16bits);
 			
+			sample.data.set_size(sample_size);
+
 			sample.data.set_loop_end( sample.data.get_loop_end() + sample.data.get_loop_begin() );
 
 			sample.def_panning_on=true;
@@ -564,7 +580,7 @@ Loader::Error Loader_XM::load_instrument_internal(Instrument *p_instr,bool p_xi,
 			sample.name=instrname;
 
 
-			if (sample.data.get_size()==0) continue; //screw you d00d
+			if (sample.data.is_empty()) continue; //screw you d00d
 			sample.in_use=true;
 			samples.push_back(sample);
 			sample_index[j]=samples.size()-1;
@@ -578,39 +594,24 @@ Loader::Error Loader_XM::load_instrument_internal(Instrument *p_instr,bool p_xi,
 
 			Sample *sample=&samples[sample_index[j]];
 
-			sample->data.set_data_ptr( (Sint16 *)malloc(sample->data.get_size()*(sample->data.is_16bit()?2:1)), sample->data.get_size(), sample->data.is_16bit() );
 
-			if (sample->data.is_16bit()) {
+			sample_int_t sampleval;
+			sample_int_t old=0;
+			sample_int_t newsample;
 
-				Sint16 *sampleptr=(Sint16*)&sample->data.get_data_16()[0];
-				Sint16 sampleval,old;
-
-				old=0;
-				for (int k=0;k<sample->data.get_size();k++) {
-
-					Sint16 newsample;
-					sampleval=reader.get_word();
-					newsample=sampleval+old;
-					old=newsample;
-					*sampleptr=newsample;
-					sampleptr++;
-				}
-			} else {
-
-				Sint8 *sampleptr=(Sint8*)&sample->data.get_data_8()[0];
-				Sint8 sampleval,old;
-
-				old=0;
-				for (int k=0;k<sample->data.get_size();k++) {
-
-					Sint8 newsample;
-					sampleval=reader.get_byte();
-					newsample=sampleval+old;
-					old=newsample;
-					*sampleptr=newsample;
-					sampleptr++;
-				}
+			sample->data.seek(0);
+			for(size_t ix=0; ix<sample_size; ix++) {
+				if(sample_is_16bits)
+					sampleval=CONVERT_FROM_TYPE(Sint16, reader.get_word());
+				else
+					sampleval=CONVERT_FROM_TYPE(Sint8, reader.get_byte());
+				
+				newsample=sampleval+old;
+				old=newsample;
+				
+				sample->data.put_sample(&newsample);
 			}
+
 		}
 
 		for (int j=0;j<96;j++) {
@@ -677,13 +678,8 @@ string Loader_XM::get_sample_name(int p_sample_index) {
 }
 void Loader_XM::add_sample_to_song(int p_sample_index,int p_dest_index,bool create_instrument) {
 
-  	if (song->get_sample(p_dest_index)->in_use) {
-
-		song->get_sample(p_dest_index)->data.set_data_ptr(NULL);
-     	}
 
 	*song->get_sample(p_dest_index)=samples[p_sample_index];
- 	samples[p_sample_index].data.release_data_ptr();
 
   	if (create_instrument) {
 
@@ -761,10 +757,10 @@ Loader::Error Loader_XM::load_instrument(const char *p_filename,int p_dest_index
 			*song->get_sample(new_slot)=samples[i];
    			slot_replace.push_back(new_slot);
 
-		} else if (samples[i].data.get_data_16()!=NULL) {
+		} else if (!samples[i].data.is_empty()) {
 
 			//there's no room aviable for our sample (IT sux, eh? ;)
-			samples[i].data.set_data_ptr(NULL);
+			samples[i].data.set_size(0);
    			slot_replace.push_back(EMPTY_FIELD);
 
 		}
@@ -849,13 +845,6 @@ void Loader_XM::transfer_data_to_song() {
 }
 
 void Loader_XM::free_info(bool free_sampledata) {
-
-	if (free_sampledata)
-		for (int x=0;x<(int)samples.size();x++) {
-			if (samples[x].data.get_data_16()!=NULL)
-				samples[x].data.set_data_ptr(NULL);
-		}
-
 	samples.clear();
 	instruments.clear();
 }
