@@ -36,7 +36,9 @@ public:
 		Sint64 sample_offset;
 		Sint32 increment;
 		Sint32 samples_to_mix;
-		Uint8 fractional_size;
+		int panning;
+		size_t mixfreq;
+		size_t current_frequency;
 
 		float l_volume;
 		float r_volume;
@@ -50,6 +52,13 @@ public:
                         IIR_SVF::Coeffs coeffs;
 			float hist_a1,hist_a2,hist_b1,hist_b2; //prev is previous input, hist and hist 2 are filter history
 		} filter;
+		class Fraction {
+			public:
+                        	size_t num;
+                        	size_t den;
+                        	size_t operator *(size_t);
+			}increment_fraction;
+
 	};
 
 
