@@ -47,7 +47,6 @@ public:
 
 	inline void set_sample_offset(Sint64 p_offset);
 	inline void set_increment(Sint64 p_increment);
-	inline void set_fractional(Uint8 p_fract);
 	inline void set_samples_to_mix(int p_amount);
 	inline void set_l_volume(float p_volume);
 	inline void set_r_volume(float p_volume);
@@ -87,12 +86,6 @@ inline void Resampler_Instance::set_increment(Sint64 p_increment) {
 
 }
 
-inline void Resampler_Instance::set_fractional(Uint8 p_fract) {
-
-	 mixdata.fractional_size=p_fract;
-
-}
-
 inline void Resampler_Instance::set_samples_to_mix(int p_amount) {
 
 	 mixdata.samples_to_mix=p_amount;
@@ -138,7 +131,7 @@ inline Sint64 Resampler_Instance::get_sample_offset() {
  	return mixdata.sample_offset;
 }
 
-inline void Resampler_Instance:: set_current_resampler(int p_index) {
+inline void Resampler_Instance::set_current_resampler(int p_index) {
 
 	if (current_resampler==p_index)
 		return;
@@ -146,10 +139,7 @@ inline void Resampler_Instance:: set_current_resampler(int p_index) {
 	if (p_index<0) {
 		current_resampler=DEFAULT_RESAMPLER;
 	} else if (p_index>=resampler_manager->get_resampler_count())  {
-
-
-		ERROR("Invalid Resampler!");
-		return;
+		throw Out_Of_Bounds(__FILE__, __LINE__, "Invalid resampler!");
 	}
 
 	current_resampler=p_index;
@@ -157,7 +147,7 @@ inline void Resampler_Instance:: set_current_resampler(int p_index) {
 
 void Resampler_Instance::mix() {
 
-	int resampler_idx=(current_resampler<0)?resampler_manager->get_default_resampler():current_resampler;
+	int resampler_idx=current_resampler;
 
 	resampler_manager->get_resampler(resampler_idx)->mix(&mixdata);
 }
