@@ -30,11 +30,13 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <new> // bad_alloc
+#include "Error.h"
 #include "sound_driver_manager.h"
+#include "message_box.h"
 
 Sound_Driver_Manager * Sound_Driver_Manager::singleton_instance=NULL;
 
-
 Sound_Driver_Manager * Sound_Driver_Manager::get_singleton_instance() {
 
 	return singleton_instance;
@@ -43,8 +45,8 @@ Sound_Driver_Manager * Sound_Driver_Manager::get_singleton_instance() {
 
 void Sound_Driver_Manager::add_mixer(Mixer_Base* p_mixer) {
 
-	if (variables_lock) variables_lock->grab();
-	if (driver_lock) driver_lock->grab(); //we need an extra lock for this
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
+	if (driver_lock) driver_lock->grab(__FILE__, __LINE__); //we need an extra lock for this
 	mixer_list.push_back(p_mixer);
 	if (driver_lock) driver_lock->release();
 	if (variables_lock) variables_lock->release();
@@ -54,8 +56,8 @@ void Sound_Driver_Manager::add_mixer(Mixer_Base* p_mixer) {
 
 void Sound_Driver_Manager::remove_mixer(Mixer_Base* p_mixer) {
 
-	if (variables_lock) variables_lock->grab();
-	if (driver_lock) driver_lock->grab(); //we need an extra lock for this
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
+	if (driver_lock) driver_lock->grab(__FILE__, __LINE__); //we need an extra lock for this
 
 	for (int i=(mixer_list.size()-1);i>=0;i--) {
 
@@ -128,7 +130,7 @@ void Sound_Driver_Manager::set_active_driver(int p_driver_index) {
 	if (p_driver_index==active_driver_index) return;
 	bool driver_was_active=false;
 
-	if (variables_lock) variables_lock->grab();
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
 	if (active_driver_index>=0) {
 
@@ -152,7 +154,7 @@ void Sound_Driver_Manager::stop_active_driver(bool p_lock) {
 	if (active_driver_index<0) return;
 
 	if (p_lock)
-		if (variables_lock) variables_lock->grab();
+		if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
 	if (driver_list[active_driver_index]->is_active())
 		driver_list[active_driver_index]->finish();
@@ -170,10 +172,10 @@ bool Sound_Driver_Manager::poll_active_driver() {
         Sound_Driver::Status driver_status=Sound_Driver::IDLE;
 
 	if (driver_list[active_driver_index]->accepts_blocking()) {
-		if (variables_lock) variables_lock->grab(); //commenting this out, since the mutex takes the whole thing
+		if (variables_lock) variables_lock->grab(__FILE__, __LINE__); //commenting this out, since the mutex takes the whole thing
         } else {
 		if (variables_lock) {
-			if (variables_lock->try_grab())
+			if (variables_lock->try_grab(__FILE__, __LINE__))
 				return false;
 		}
 	}
@@ -217,12 +219,18 @@ void Sound_Driver_Manager::reset_active_driver() {
 
 	if (active_driver_index<0) return;
 
-	if (variables_lock) variables_lock->grab();
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
-	if (driver_list[active_driver_index]->is_active()) {
+	try {
+		if (driver_list[active_driver_index]->is_active()) {
 
-		driver_list[active_driver_index]->finish();
+			driver_list[active_driver_index]->finish();
 
+		}
+	} catch (Error E) {
+		if(variables_lock)
+			variables_lock->release();
+		throw E;
 	}
 
 	internal_driver_init();
@@ -246,7 +254,7 @@ void Sound_Driver_Manager::request_mix_frequency(int p_mix_frequency) {
 
         bool need_reinit=false;
 
-	if (variables_lock) variables_lock->grab();
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
 	if (driver_list[active_driver_index]->is_active()) {
 
@@ -272,7 +280,7 @@ void Sound_Driver_Manager::request_mix_stereo(bool p_mix_stereo) {
 	
         bool need_reinit=false;
 
-	if (variables_lock) variables_lock->grab();
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
 	if (driver_list[active_driver_index]->is_active()) {
 
@@ -300,7 +308,7 @@ void Sound_Driver_Manager::request_mix_16bits(bool p_mix_16bits) {
 	
         bool need_reinit=false;
 
-	if (variables_lock) variables_lock->grab();
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
 	if (driver_list[active_driver_index]->is_active()) {
 
@@ -320,22 +328,24 @@ void Sound_Driver_Manager::request_mix_16bits(bool p_mix_16bits) {
 
 void Sound_Driver_Manager::request_buffer_size(int p_buffsize) {
 
+	///// FIXME: The start() and finish() methods in this program
+	///// can throw exceptions, which will cause variables_lock->release()
+	///// to be skipped over, which will lead to a deadlock.
+
 	tmp_mix_buffsize=p_buffsize;
 
 	if (active_driver_index<0) return;
 
         bool need_reinit=false;
 
-	if (variables_lock) variables_lock->grab();
+	if (variables_lock) variables_lock->grab(__FILE__, __LINE__);
 
 	if (driver_list[active_driver_index]->is_active()) {
-
 			driver_list[active_driver_index]->finish();
 	  		need_reinit=true;
-
 	}
 
-	if (driver_lock) driver_lock->grab(); //we need an extra lock for this
+	if (driver_lock) driver_lock->grab(__FILE__, __LINE__); //we need an extra lock for this
 	driver_list[active_driver_index]->request_buffer_size(p_buffsize);
 	if (driver_lock) driver_lock->release();
 
@@ -378,12 +388,18 @@ void Sound_Driver_Manager::internal_driver_init() {
 
 	if (active_driver_index<0) return;
 
-	driver_list[active_driver_index]->request_mix_frequency(tmp_mix_frequency);
-	driver_list[active_driver_index]->request_mix_stereo(tmp_mix_stereo);
-	driver_list[active_driver_index]->request_mix_16bits(tmp_mix_16bits);
-	driver_list[active_driver_index]->request_buffer_size(tmp_mix_buffsize);
-	driver_list[active_driver_index]->init();
-	sampling_rate_changed_signal.emit( driver_list[active_driver_index]->get_mix_frequency() );
+	try {
+		driver_list[active_driver_index]->request_mix_frequency(tmp_mix_frequency);
+		driver_list[active_driver_index]->request_mix_stereo(tmp_mix_stereo);
+		driver_list[active_driver_index]->request_mix_16bits(tmp_mix_16bits);
+		driver_list[active_driver_index]->request_buffer_size(tmp_mix_buffsize);
+		driver_list[active_driver_index]->init();
+		sampling_rate_changed_signal.emit( driver_list[active_driver_index]->get_mix_frequency() );
+	} catch (Error E) {
+		message_box("Error", E.what(), "OK");
+	} catch (std::bad_alloc B) {
+		message_box("SENILE.SYS loaded", "Out of memory", "Chinga!");
+	} 
 }
 int Sound_Driver_Manager::get_mix_frequency() {
 	if (active_driver_index<0)
