@@ -25,9 +25,19 @@
 
 #if (__GNUC__ == 3) || (__GNUC__ > 3)
 
-#include <ext/hash_map>
-    using __gnu_cxx::hash_map;
 
+	#ifdef USING_STLPORT
+		#include <hash_map>
+			using std::hash_map;
+			using std::hash;
+			
+	#else
+		#include <ext/hash_map>
+			using __gnu_cxx::hash_map;
+			using __gnu_cxx::hash;
+	#endif
+	
+    
 #else
 
 
