@@ -72,7 +72,7 @@ class Sound_Driver_JACK : public Sound_Driver  {
 
 	int jack_callback_nframes;
 
-	Sound_Driver::Status Sound_Driver_JACK::process();
+	Sound_Driver::Status process();
 
         static int process_jack_callback(jack_nframes_t nframes,void *arg);
         static int jack_set_mixfreq(jack_nframes_t nframes,void *arg);
