@@ -182,9 +182,10 @@ void Sample_Editor_Format::update_format() {
 	updating=true;
 
 	char auxbuf[40];
+	auxbuf[39]=0;
 
 	entry_depth->setText( (sample_data->is_16bit()?"16 bits":"8 bits"));
-	sprintf(auxbuf,"%i",sample_data->get_size());
+	snprintf(auxbuf,39,"%i",sample_data->get_size());
 	entry_size->setText(auxbuf);
 	spin_base_freq->setValue(sample_data->get_c5_freq());
 
