@@ -47,7 +47,8 @@ void Sample_Viewer_Zoom::update_zoom_bar() {
 	zoom_slider->setValue((int)(sample_viewer->get_zoom()*100));
 
 	char buf[40];
-	sprintf(buf," %.2f%%",sample_viewer->get_zoom()*100.f);
+	buf[39]=0;
+	snprintf(buf,39," %.2f%%",sample_viewer->get_zoom()*100.f);
 	zoom_slider_label->setText(buf);
 
 }
