@@ -65,11 +65,12 @@ void CColor_List::save_settings(ConfigHandler *p_config_handler) {
 
 	p_config_handler->add_section("Color Theme");
 	static char buf[40];
+	buf[39]=0;
 	for (int i=0;i<(int)color_list.size();i++) {
 
 
 		string prop_name=(string)color_list[i].section.ascii() + ":-_-:" + (string)color_list[i].name.ascii();
-		sprintf(buf,"%i,%i,%i",color_list[i].bridge->get_color()->red(),color_list[i].bridge->get_color()->green(),color_list[i].bridge->get_color()->blue());
+		snprintf(buf,39,"%i,%i,%i",color_list[i].bridge->get_color()->red(),color_list[i].bridge->get_color()->green(),color_list[i].bridge->get_color()->blue());
 
 		p_config_handler->add_property("Color Theme",prop_name,buf);
 	}
