@@ -14,27 +14,29 @@
 
 
 #include "common/components/audio/effect.h"
+#include "plugins/effects/custom/custom_fx_param_list.h"
 
 /**
 @author Juan Linietsky
 */
 class Effect_Amp : public Effect{
 
-	int percent;
 
-	Int_Property_Bridge prop_percent;
+	Custom_FX_Param_List *params;
+	
+	void set_sampling_rate(int p_rate) {}
 
+	Effect_Amp();
+	Effect_Amp(Effect::Parameters *p_params);	
 public:
 
 	void reset();
-        void process_buffer(sample_32s_t* p_buffer,int p_length,bool p_stereo_samples,int p_buffer_freq);
-	string get_name();
-	string get_display_name();
-	list<Property_Bridge*> get_properties();
+        void process_buffer(sample_t* p_buffer,int p_length);
+
+        static Effect * create_this(Effect::Parameters *p_params) { return new Effect_Amp(p_params); }
+        static Effect::Parameters * create_parameters();
 
-        static Effect * create_this() { return new Effect_Amp; }
 
-	Effect_Amp();
 	~Effect_Amp();
 
 };
