@@ -16,6 +16,8 @@
 #include "common/components/audio/effect.h"
 #include <vector>
 	using std::vector;
+	
+#include "plugins/effects/custom/custom_fx_param_list.h"
 /**
 @author Juan Linietsky
 */
@@ -23,21 +25,24 @@ class Freeverb_Effect : public Effect {
 
 	revmodel freeverb; //freeverb object
 
+	
+	enum ParamNames {
+		
+		PARAM_ROOM_SIZE,
+		PARAM_DAMP,
+		PARAM_WET,
+		PARAM_DRY,
+		PARAM_WIDTH
+	};
+		
 	struct Params {
-		int room_size;
-		int damp;
-		int wet;
-		int dry;
-		int width;
-		int old_freq;
+		float room_size;
+		float damp;
+		float wet;
+		float dry;
+		float width;
 	} current_parm,bridge_parm;
 
-	Int_Property_Bridge room_size_bridge;
-	Int_Property_Bridge damp_bridge;
-	Int_Property_Bridge wet_bridge;
-	Int_Property_Bridge dry_bridge;
-	Int_Property_Bridge width_bridge;
-
 	enum {
 		INTERNAL_BUFFER_SIZE=8192
 	};
@@ -49,17 +54,18 @@ class Freeverb_Effect : public Effect {
 
 	void check_params_changed();
 
+	Freeverb_Effect(Effect::Parameters *p_parameters);
+	
+	Custom_FX_Param_List * parameters;
+	
 public:
 	void reset();
-        void process_buffer(sample_32s_t* p_buffer,int p_length,bool p_stereo_samples,int p_buffer_freq);
-	string get_name();
-	string get_display_name();
-	list<Property_Bridge*> get_properties();
+        void process_buffer(sample_t* p_buffer,int p_length);
 
-        static Effect * create_this() { return new Freeverb_Effect; }
+        static Effect * create_this(Effect::Parameters *p_parameters) { return new Freeverb_Effect(p_parameters); }
+        static Effect::Parameters * create_parameters();
 
 
-	Freeverb_Effect();
 	~Freeverb_Effect();
 
 };
